﻿using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Tsi1.BusinessLayer.Dtos;
using Tsi1.BusinessLayer.Helpers;
using Tsi1.BusinessLayer.Interfaces;

namespace Tsi1.Api.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class EvaluationController : ControllerBase
    {
        private readonly IEvaluationService _evaluationService;
        private readonly IEvaluationTypeService _evaluationTypeService;


        public EvaluationController(IEvaluationService evaluationService, IEvaluationTypeService evaluationTypeService)
        {
            _evaluationService = evaluationService;
            _evaluationTypeService = evaluationTypeService;
        }

        [Authorize(Roles = UserTypes.Student)]
        [HttpPost("Registration/{evaluationId}")]
        public async Task<IActionResult> GetAll(int evaluationId)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _evaluationService.Registration(evaluationId, userId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.Student)]
        [HttpPost("CancelRegistration/{evaluationId}")]
        public async Task<IActionResult> CancelRegistration(int evaluationId)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _evaluationService.CancelRegistration(evaluationId, userId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.Student)]
        [HttpPost("SubmitLaboratory/{evaluationId}")]
        public async Task<IActionResult> SubmitLaboratory(FileDto fileDto, int evaluationId)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _evaluationService.SubmitLaboratory(fileDto, evaluationId, userId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.Student)]
        [HttpDelete("DeleteLaboratory/{submissionId}")]
        public async Task<IActionResult> DeleteLaboratory(int submissionId)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _evaluationService.DeleteLaboratory(submissionId, userId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.Student)]
        [HttpGet("GetMyEvaluationInscriptions/{courseId}")]
        public async Task<IActionResult> GetMyEvaluationInscriptions(int courseId)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _evaluationService.GetMyEvaluationInscriptions(userId, courseId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.Professor)]
        [HttpGet("GetAllEvaluationInscriptions/{evaluationId}")]
        public async Task<IActionResult> GetAllEvaluationInscriptions(int evaluationId)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _evaluationService.GetAllEvaluationInscriptions(userId, evaluationId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        //QualifyEvaluationInscription(EvaluationInscriptionModifyDto evaluationInscriptionDto, int userId);
        [Authorize(Roles = UserTypes.Professor)]
        [HttpPost("QualifyEvaluationInscription")]
        public async Task<IActionResult> SubmitLaboratory(EvaluationInscriptionModifyDto evaluationInscriptionDto)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _evaluationService.QualifyEvaluationInscription(evaluationInscriptionDto, userId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.Student + ", " + UserTypes.FacultyAdmin + ", " + UserTypes.Professor)]
        [HttpGet("GetEvaluationTypes")]
        public async Task<IActionResult> GetEvaluationTypes()
        {
            var result = await _evaluationTypeService.GetAll();

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.Student + ", " + UserTypes.FacultyAdmin + ", " + UserTypes.Professor)]
        [HttpGet("GetEvaluationTypeById/{evaluationTypeId}")]
        public async Task<IActionResult> GetEvaluationTypeById(int evaluationTypeId)
        {
            var result = await _evaluationTypeService.GetById(evaluationTypeId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }
    }
}
