using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Tsi1.BusinessLayer.Dtos;
using Tsi1.BusinessLayer.Helpers;
using Tsi1.BusinessLayer.Interfaces;

namespace Tsi1.Api.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class ForumController : ControllerBase
    {
        private readonly IForumService _forumService;

        public ForumController(IForumService forumService)
        {
            _forumService = forumService;
        }

        [Authorize(Roles = UserTypes.Student + ", " + UserTypes.Professor)]
        [HttpGet("GetForums/{sectionId}")]
        public async Task<IActionResult> GetForums(int sectionId)
        {
            var result = await _forumService.GetForums(sectionId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        //[Authorize(Roles = UserTypes.Professor)]
        //[HttpPost("Create")]
        //public async Task<IActionResult> Create(ForumCreateDto newForum)
        //{
        //    var result = await _forumService.Create(newForum);

        //    if (result.HasError)
        //    {
        //        return BadRequest(result.Message);
        //    }

        //    return Ok(result.Data);
        //}

        [Authorize(Roles = UserTypes.Professor)]
        [HttpPut("{id}")]
        public async Task<IActionResult> Modify(int id, ForumModifyDto forum)
        {
            var tenantId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "TenantId").Value);
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            forum.TenantId = tenantId;
            forum.ProfessorUserId = userId;

            var result = await _forumService.Modify(id, forum);
            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.Professor)]
        [HttpDelete("Delete/{forumId}")]
        public async Task<IActionResult> Delete(int forumId)
        {
            var result = await _forumService.Delete(forumId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok();
        }

        [Authorize(Roles = UserTypes.Student)]
        [HttpGet("Subscribe/{forumId}")]
        public async Task<IActionResult> Subscribe(int forumId)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _forumService.Subscribe(forumId, userId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok();
        }

    }
}
