﻿using AutoMapper;
using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;
using Tsi1.BusinessLayer.Dtos;
using Tsi1.BusinessLayer.Helpers;
using Tsi1.BusinessLayer.Interfaces;
using Tsi1.DataLayer;

namespace Tsi1.BusinessLayer.Services
{
    public class EvaluationTypeService : IEvaluationTypeService
    {
        private readonly Tsi1Context _context;
        private readonly IMapper _mapper;

        public EvaluationTypeService(Tsi1Context context, IMapper mapper)
        {
            _context = context;
            _mapper = mapper;
        }

        public async Task<ServiceResult<List<EvaluationTypeDto>>> GetAll()
        {
            var result = new ServiceResult<List<EvaluationTypeDto>>();

            var evaluationTypes = await _context.EvaluationTypes.ToListAsync();

            result.Data = _mapper.Map<List<EvaluationTypeDto>>(evaluationTypes);

            return result;
        }

        public async Task<ServiceResult<EvaluationTypeDto>> GetById(int id)
        {
            var result = new ServiceResult<EvaluationTypeDto>();

            var evaluationType = await _context.EvaluationTypes.FirstOrDefaultAsync(x => x.Id == id);

            if (evaluationType == null)
            {
                result.HasError = true;
                result.AddMessage(string.Format(ErrorMessages.EvaluationTypeDoesNotExist, id));
                return result;
            }

            result.Data = _mapper.Map<EvaluationTypeDto>(evaluationType);

            return result;
        }
    }
}
