﻿using AutoMapper;
using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;
using Tsi1.BusinessLayer.Dtos;
using Tsi1.BusinessLayer.Helpers;
using Tsi1.BusinessLayer.Interfaces;
using Tsi1.DataLayer;

namespace Tsi1.BusinessLayer.Services
{
    public class SectionItemTypeService : ISectionItemTypeService
    {
        private readonly Tsi1Context _context;
        private readonly IMapper _mapper;

        public SectionItemTypeService(Tsi1Context context, IMapper mapper)
        {
            _context = context;
            _mapper = mapper;
        }
        public async Task<ServiceResult<List<SectionItemTypeDto>>> GetAll()
        {
            var result = new ServiceResult<List<SectionItemTypeDto>>();
            var sectionItemTypes = await _context.SectionItemTypes.ToListAsync();

            result.Data = _mapper.Map<List<SectionItemTypeDto>>(sectionItemTypes);
            return result;
        }

        public async Task<ServiceResult<SectionItemTypeDto>> GetById(int id)
        {
            var result = new ServiceResult<SectionItemTypeDto>();

            var sectionItemType = await _context.SectionItemTypes.FirstOrDefaultAsync(x => x.Id == id);
            if (sectionItemType == null)
            {
                result.HasError = true;
                result.AddMessage(string.Format(ErrorMessages.SectionItemTypeDoesNotExist, id));
                return result;
            }

            result.Data = _mapper.Map<SectionItemTypeDto>(sectionItemType);
            return result;
        }
    }
}
