﻿using Microsoft.EntityFrameworkCore.Migrations;
using Npgsql.EntityFrameworkCore.PostgreSQL.Metadata;

namespace Tsi1.DataLayer.Migrations
{
    public partial class addevaluationentities : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.AddColumn<bool>(
                name: "IsSubmission",
                table: "Files",
                nullable: false,
                defaultValue: false);

            migrationBuilder.AddColumn<int>(
                name: "SubmissionId",
                table: "Files",
                nullable: true);

            migrationBuilder.AddColumn<int>(
                name: "EvaluationId",
                table: "Activities",
                nullable: true);

            migrationBuilder.CreateTable(
                name: "EvaluationTypes",
                columns: table => new
                {
                    Id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    Name = table.Column<string>(type: "character varying(50)", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_EvaluationTypes", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Evaluations",
                columns: table => new
                {
                    Id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    EvaluationTypeId = table.Column<int>(nullable: false),
                    IsCompleted = table.Column<bool>(nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Evaluations", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Evaluations_EvaluationTypes_EvaluationTypeId",
                        column: x => x.EvaluationTypeId,
                        principalTable: "EvaluationTypes",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "EvaluationInscriptions",
                columns: table => new
                {
                    EvaluationId = table.Column<int>(nullable: false),
                    StudentId = table.Column<int>(nullable: false),
                    Grade = table.Column<decimal>(type: "decimal(5,2)", nullable: false),
                    HasAttended = table.Column<bool>(nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_EvaluationInscriptions", x => new { x.EvaluationId, x.StudentId });
                    table.ForeignKey(
                        name: "FK_EvaluationInscriptions_Evaluations_EvaluationId",
                        column: x => x.EvaluationId,
                        principalTable: "Evaluations",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_EvaluationInscriptions_Students_StudentId",
                        column: x => x.StudentId,
                        principalTable: "Students",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "Submissions",
                columns: table => new
                {
                    Id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    StudentId = table.Column<int>(nullable: false),
                    FileId = table.Column<int>(nullable: false),
                    Grade = table.Column<decimal>(type: "decimal(5,2)", nullable: false),
                    IsCompleted = table.Column<bool>(nullable: false),
                    EvaluationId = table.Column<int>(nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Submissions", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Submissions_Evaluations_EvaluationId",
                        column: x => x.EvaluationId,
                        principalTable: "Evaluations",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "FK_Submissions_Students_StudentId",
                        column: x => x.StudentId,
                        principalTable: "Students",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateIndex(
                name: "IX_Files_SubmissionId",
                table: "Files",
                column: "SubmissionId",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_Activities_EvaluationId",
                table: "Activities",
                column: "EvaluationId");

            migrationBuilder.CreateIndex(
                name: "IX_EvaluationInscriptions_StudentId",
                table: "EvaluationInscriptions",
                column: "StudentId");

            migrationBuilder.CreateIndex(
                name: "IX_Evaluations_EvaluationTypeId",
                table: "Evaluations",
                column: "EvaluationTypeId");

            migrationBuilder.CreateIndex(
                name: "IX_EvaluationTypes_Name",
                table: "EvaluationTypes",
                column: "Name",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_Submissions_EvaluationId",
                table: "Submissions",
                column: "EvaluationId");

            migrationBuilder.CreateIndex(
                name: "IX_Submissions_StudentId_FileId",
                table: "Submissions",
                columns: new[] { "StudentId", "FileId" },
                unique: true);

            migrationBuilder.AddForeignKey(
                name: "FK_Activities_Evaluations_EvaluationId",
                table: "Activities",
                column: "EvaluationId",
                principalTable: "Evaluations",
                principalColumn: "Id",
                onDelete: ReferentialAction.Restrict);

            migrationBuilder.AddForeignKey(
                name: "FK_Files_Submissions_SubmissionId",
                table: "Files",
                column: "SubmissionId",
                principalTable: "Submissions",
                principalColumn: "Id",
                onDelete: ReferentialAction.Restrict);
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropForeignKey(
                name: "FK_Activities_Evaluations_EvaluationId",
                table: "Activities");

            migrationBuilder.DropForeignKey(
                name: "FK_Files_Submissions_SubmissionId",
                table: "Files");

            migrationBuilder.DropTable(
                name: "EvaluationInscriptions");

            migrationBuilder.DropTable(
                name: "Submissions");

            migrationBuilder.DropTable(
                name: "Evaluations");

            migrationBuilder.DropTable(
                name: "EvaluationTypes");

            migrationBuilder.DropIndex(
                name: "IX_Files_SubmissionId",
                table: "Files");

            migrationBuilder.DropIndex(
                name: "IX_Activities_EvaluationId",
                table: "Activities");

            migrationBuilder.DropColumn(
                name: "IsSubmission",
                table: "Files");

            migrationBuilder.DropColumn(
                name: "SubmissionId",
                table: "Files");

            migrationBuilder.DropColumn(
                name: "EvaluationId",
                table: "Activities");
        }
    }
}
